.. _destrieux_2009_atlas:

Destrieux atlas
===============

Access
------
See :func:`nilearn.datasets.fetch_atlas_destrieux_2009`.

Notes
-----
Anatomical :term:`parcellation` of the cortex based on sulco-gyral patterns
(:footcite:t:`Destrieux2010`) distributed with Freesurfer (:footcite:t:`Dale1999`,
:footcite:t:`Fischl1999b`) in fsaverage5 standard surface space.

See also :footcite:t:`Fischl2004` and :footcite:t:`Destrieux2009`.

Content
-------
    :'map_left': :term:`parcellation` on left hemisphere in freesurfer annot format
    :'map_right': :term:`parcellation` on right hemisphere in freesurfer annot format

References
----------

.. footbibliography::

License
-------
unknown
